@@ -1,18 +1,11 @@
 package String::FlexMatch;
-
+use 5.006;
 use strict;
 use warnings;
-
-
 use base 'Class::Accessor::Complex';
-
-
-our $VERSION = '0.11';
-
-
+our $VERSION = '0.13';
 __PACKAGE__->mk_new;
 
-
 # Back in Test::More 0.45 the sane view was taken that if an object overrides
 # stringification, it probably does so for a reason, and that stringification
 # defines how the object wants to be compared. Newer versions of Test::More
@@ -22,57 +15,46 @@ __PACKAGE__->mk_new;
 #
 # You might say that's an evil hack and I might say I don't care. If you use
 # String::FlexMatch you subscribe to my point of view.
-
 #require Test::Builder;
 #no warnings 'redefine';
 #*Test::Builder::_unoverload = sub {};
-
-
 use overload
-    '""' => \&as_string,
-    'eq' => \&is_eq,
-    'ne' => \&is_ne,
-    '==' => \&is_eq;
-
-
-sub init {}   # so potential subclasses can override
-
+  '""' => \&as_string,
+  'eq' => \&is_eq,
+  'ne' => \&is_ne,
+  '==' => \&is_eq;
+sub init { }    # so potential subclasses can override
 
 sub string {
     my $self = shift;
     @_ ? $self->{string} = shift : $self->{string};
 }
 
-
 sub force_regex {
     return unless defined $_[1];
-    ref $_[1] eq 'Regexp' ? $_[1] : qr/$_[1]/
+    ref $_[1] eq 'Regexp' ? $_[1] : qr/$_[1]/;
 }
 
-
 sub regex {
     my $self = shift;
-    @_ ? $self->{regex} = $self->force_regex(+shift)
-       : $self->force_regex($self->{regex});
+    @_
+      ? $self->{regex} = $self->force_regex(+shift)
+      : $self->force_regex($self->{regex});
 }
 
-
 sub force_code {
     return unless defined $_[1];
-    ref $_[1] eq 'CODE' ? $_[1] : eval $_[1]
+    ref $_[1] eq 'CODE' ? $_[1] : eval $_[1];
 }
 
-
 sub code {
     my $self = shift;
-    @_ ? $self->{code} = $self->force_code(+shift)
-       : $self->force_code($self->{code});
+    @_
+      ? $self->{code} = $self->force_code(+shift)
+      : $self->force_code($self->{code});
 }
-
-
 sub as_string { $_[0]->choice_attr }
 
-
 sub is_eq {
     my ($lhs, $rhs) = @_;
 
@@ -80,41 +62,34 @@ sub is_eq {
     # there's no match
     return !defined $rhs unless defined $lhs;
     return !defined $lhs unless defined $rhs;
-
-    my $lhs_val = ref($lhs) && $lhs->isa('String::FlexMatch')
-        ? $lhs->choice_attr : "$lhs";
-    my $rhs_val = ref($rhs) && $rhs->isa('String::FlexMatch')
-        ? $rhs->choice_attr : "$rhs";
+    my $lhs_val =
+      ref($lhs) && $lhs->isa('String::FlexMatch') ? $lhs->choice_attr : "$lhs";
+    my $rhs_val =
+      ref($rhs) && $rhs->isa('String::FlexMatch') ? $rhs->choice_attr : "$rhs";
     my $key = sprintf "%s_%s", map { ref || 'STRING' } $lhs_val, $rhs_val;
-
     our $match ||= {
         STRING_STRING => sub { $_[0] eq $_[1] },
         STRING_Regexp => sub { $_[0] =~ $_[1] },
         STRING_CODE   => sub { $_[1]->($_[0]) },
         Regexp_STRING => sub { $_[1] =~ $_[0] },
         Regexp_Regexp => sub { die "can't compare two regexes" },
-        Regexp_CODE   => sub { die "can't compare a regex to a string" },
-        CODE_STRING   => sub { $_[0]->($_[1]) },
-        CODE_Regexp   => sub { die "can't compare a coderef to a regex" },
-        CODE_CODE     => sub { die "can't compare two coderefs" },
+        Regexp_CODE => sub { die "can't compare a regex to a string" },
+        CODE_STRING => sub { $_[0]->($_[1]) },
+        CODE_Regexp => sub { die "can't compare a coderef to a regex" },
+        CODE_CODE   => sub { die "can't compare two coderefs" },
     };
-
     $match->{$key}->($lhs_val, $rhs_val);
 }
-
-
 sub is_ne { !is_eq(@_) }
 
-
 sub choice_attr {
     my $self = shift;
-    defined $self->string ? $self->string :
-    defined $self->regex  ? $self->regex  :
-    defined $self->code   ? $self->code   :
-    undef;
+        defined $self->string ? $self->string
+      : defined $self->regex  ? $self->regex
+      : defined $self->code   ? $self->code
+      :                         undef;
 }
 
-
 # If this module is used with YAML::Active, we want it to dump as a
 # String::Flex::NoOverload object. If this sub wasn't there, YAML would
 # stringify the String::FlexMatch object, which would produce a normal string
@@ -132,32 +107,22 @@ sub choice_attr {
 # The last piece of the puzzle is to make String::FlexMatch::NoOverload
 # inherit from String::FlexMatch. That way, when re-Loading the above YAML,
 # the expected behaviour of the flex string still works.
-
-
 sub prepare_dump { @String::FlexMatch::NoOverload::ISA = () }
 sub finish_dump  { @String::FlexMatch::NoOverload::ISA = 'String::FlexMatch' }
 
-
 sub yaml_dump {
     my $self = shift;
     my $dump_self;
     %$dump_self = %$self;
     bless $dump_self, 'String::FlexMatch::NoOverload';
 }
-
-
 @String::FlexMatch::NoOverload::ISA = 'String::FlexMatch';
-
-
 1;
-
 __END__
 
-
-
 =head1 NAME
 
-String::FlexMatch - flexible ways to match a string
+String::FlexMatch - Flexible ways to match a string
 
 =head1 SYNOPSIS
 
@@ -165,20 +130,20 @@ String::FlexMatch - flexible ways to match a string
 
   my $s = String::FlexMatch->new(string => 'foobar');
   if ($s eq 'foobar') {
-    ...
+    # ...
   }
 
-  my $s = String::FlexMatch->new(regex => 'Error .* at line \d+');
+  $s = String::FlexMatch->new(regex => 'Error .* at line \d+');
   if ($s eq 'Error "foo" at line 58') {
-    ...
+    # ...
   }
 
-  my $s = String::FlexMatch->new(code => 'sub { length $_[0] < 10 }');
+  $s = String::FlexMatch->new(code => 'sub { length $_[0] < 10 }');
   # or:
   # my $s = String::FlexMatch->new(code => sub { length $_[0] < 10 });
 
   if ($s ne 'somelongstring') {
-    ...
+    # ...
   }
 
 =head1 DESCRIPTION
@@ -189,7 +154,7 @@ another more flexibly, you'd use a regular expression. And sometimes
 you have to call a subroutine with a string argument that will tell you
 whether that argument is interesting, i.e. matches in a broader sense.
 
-When running data-driven tests, you sometimes don't know per se which form
+When running data-driven tests, you sometimes don't know beforehand which form
 of matching (C<eq>, regex or code) you need. Take the following example:
 
   use Test::More;
@@ -225,37 +190,11 @@ A setup like this was the reason for writing this class. If you find
 any other uses for it, please let me know so this manpage can be expanded
 with a few cookbook-style examples.
 
-String::FlexMatch inherits from L<Class::Accessor::Complex>.
-
-The superclass L<Class::Accessor::Complex> defines these methods and
-functions:
-
-    carp(), cluck(), croak(), flatten(), mk_abstract_accessors(),
-    mk_array_accessors(), mk_boolean_accessors(),
-    mk_class_array_accessors(), mk_class_hash_accessors(),
-    mk_class_scalar_accessors(), mk_concat_accessors(),
-    mk_forward_accessors(), mk_hash_accessors(), mk_integer_accessors(),
-    mk_new(), mk_object_accessors(), mk_scalar_accessors(),
-    mk_set_accessors(), mk_singleton()
-
-The superclass L<Class::Accessor> defines these methods and functions:
-
-    _carp(), _croak(), _mk_accessors(), accessor_name_for(),
-    best_practice_accessor_name_for(), best_practice_mutator_name_for(),
-    follow_best_practice(), get(), make_accessor(), make_ro_accessor(),
-    make_wo_accessor(), mk_accessors(), mk_ro_accessors(),
-    mk_wo_accessors(), mutator_name_for(), set()
-
-The superclass L<Class::Accessor::Installer> defines these methods and
-functions:
-
-    install_accessor(), subname()
-
 =head1 METHODS
 
 =over 4
 
-=item new
+=item C<new>
 
     my $obj = String::FlexMatch->new;
     my $obj = String::FlexMatch->new(%args);
@@ -268,21 +207,11 @@ key/value pairs are set as described before.
 
 =back
 
-=head1 TAGS
-
-If you talk about this module in blogs, on del.icio.us or anywhere else,
-please use the C<stringflexmatch> tag.
-
-=head1 VERSION 
-                   
-This document describes version 0.11 of L<String::FlexMatch>.
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<<bug-string-flexmatch@rt.cpan.org>>, or through the web interface at
+Please report any bugs or feature requests through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 INSTALLATION
@@ -293,19 +222,17 @@ See perlmodinstall for information and options on installing Perl modules.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+site near you. Or see L<http://search.cpan.org/dist/String-FlexMatch/>.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2007 by Marcel GrE<uuml>nauer
+Copyright 2004-2009 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-
 =cut
-
